==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/modules/Schema/html/search/variables_76.js <==
var searchData=
[
  ['validkeys',['ValidKeys',['../../../Mapper/html/class_mapper_1_1_mapper.html#a513f3c4ca95170884638727020cc00d6',1,'Mapper::Mapper']]],
  ['validtypes',['ValidTypes',['../../../Mapper/html/class_mapper_1_1_mapper.html#a1bb39d56e19b84038417b65a6ed41ed5',1,'Mapper::Mapper']]],
  ['varchar',['VARCHAR',['../../../../lang/html/group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'Qore::SQL::VARCHAR()'],['../../../../lang/html/group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'VARCHAR()(Global Namespace)'],['../../../SqlUtil/html/namespace_sql_util.html#a3316fb866d8fee4f0bb9f9d956f9a04d',1,'SqlUtil::VARCHAR()']]],
  ['vdiscard',['VDISCARD',['../../../../lang/html/group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'Qore::VDISCARD()'],['../../../../lang/html/group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'VDISCARD()(Global Namespace)']]],
  ['vdsusp',['VDSUSP',['../../../../lang/html/group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'Qore::VDSUSP()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'VDSUSP()(Global Namespace)']]],
  ['veof',['VEOF',['../../../../lang/html/group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'Qore::VEOF()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'VEOF()(Global Namespace)']]],
  ['veol',['VEOL',['../../../../lang/html/group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'Qore::VEOL()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'VEOL()(Global Namespace)']]],
  ['veol2',['VEOL2',['../../../../lang/html/group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'Qore::VEOL2()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'VEOL2()(Global Namespace)']]],
  ['verase',['VERASE',['../../../../lang/html/group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'Qore::VERASE()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'VERASE()(Global Namespace)']]],
  ['version',['version',['../class_schema_1_1_abstract_schema.html#a9b245c4852eeababcac556f87607ce29',1,'Schema::AbstractSchema::version()'],['../../../HttpServer/html/class_http_server_1_1_http_server.html#abda322a2b64c3c6ae706454d554d189b',1,'HttpServer::HttpServer::Version()']]],
  ['version_5fcolumn',['version_column',['../class_schema_1_1_abstract_versioned_schema.html#a04a5664e0f928454f87eddcb880443a4',1,'Schema::AbstractVersionedSchema']]],
  ['version_5ftable',['version_table',['../class_schema_1_1_abstract_versioned_schema.html#ae92768484a7835db6c68c1462b2aaece',1,'Schema::AbstractVersionedSchema']]],
  ['version_5fwhere',['version_where',['../class_schema_1_1_abstract_versioned_schema.html#ac0e3c44cb6baf5234b253b125ab2ebdd',1,'Schema::AbstractVersionedSchema']]],
  ['versionmajor',['VersionMajor',['../../../../lang/html/group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'Qore::VersionMajor()'],['../../../../lang/html/group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'VersionMajor()(Global Namespace)']]],
  ['versionminor',['VersionMinor',['../../../../lang/html/group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'Qore::VersionMinor()'],['../../../../lang/html/group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'VersionMinor()(Global Namespace)']]],
  ['versionstring',['VersionString',['../../../../lang/html/group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'Qore::VersionString()'],['../../../../lang/html/group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'VersionString()(Global Namespace)']]],
  ['versionsub',['VersionSub',['../../../../lang/html/group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'Qore::VersionSub()'],['../../../../lang/html/group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'VersionSub()(Global Namespace)']]],
  ['vintr',['VINTR',['../../../../lang/html/group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'Qore::VINTR()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'VINTR()(Global Namespace)']]],
  ['vkill',['VKILL',['../../../../lang/html/group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'Qore::VKILL()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'VKILL()(Global Namespace)']]],
  ['vlnext',['VLNEXT',['../../../../lang/html/group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'Qore::VLNEXT()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'VLNEXT()(Global Namespace)']]],
  ['vmin',['VMIN',['../../../../lang/html/group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'Qore::VMIN()'],['../../../../lang/html/group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'VMIN()(Global Namespace)']]],
  ['vquit',['VQUIT',['../../../../lang/html/group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'Qore::VQUIT()'],['../../../../lang/html/group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'VQUIT()(Global Namespace)']]],
  ['vreprint',['VREPRINT',['../../../../lang/html/group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'Qore::VREPRINT()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'VREPRINT()(Global Namespace)']]],
  ['vstart',['VSTART',['../../../../lang/html/group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'Qore::VSTART()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'VSTART()(Global Namespace)']]],
  ['vstatus',['VSTATUS',['../../../../lang/html/group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'Qore::VSTATUS()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'VSTATUS()(Global Namespace)']]],
  ['vstop',['VSTOP',['../../../../lang/html/group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'Qore::VSTOP()'],['../../../../lang/html/group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'VSTOP()(Global Namespace)']]],
  ['vsusp',['VSUSP',['../../../../lang/html/group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'Qore::VSUSP()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'VSUSP()(Global Namespace)']]],
  ['vtime',['VTIME',['../../../../lang/html/group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'Qore::VTIME()'],['../../../../lang/html/group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'VTIME()(Global Namespace)']]],
  ['vwerase',['VWERASE',['../../../../lang/html/group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'Qore::VWERASE()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'VWERASE()(Global Namespace)']]]
];

==> qore-0.8.13.5.tar.bz2: qore-0.8.13.5/docs/modules/Schema/html/search/variables_76.js <==
var searchData=
[
  ['validintformats',['ValidIntFormats',['../../../Swagger/html/namespace_swagger.html#aae8fb1fb499a9d48c4164c15922addcd',1,'Swagger']]],
  ['validintformatshash',['ValidIntFormatsHash',['../../../Swagger/html/namespace_swagger.html#a87a23115627f0563e4016d308a8653c6',1,'Swagger']]],
  ['validkeys',['ValidKeys',['../../../Mapper/html/class_mapper_1_1_mapper.html#a513f3c4ca95170884638727020cc00d6',1,'Mapper::Mapper']]],
  ['validnumberformats',['ValidNumberFormats',['../../../Swagger/html/namespace_swagger.html#a4f7d133cfaffcc1b62862a46d7e5a1b4',1,'Swagger']]],
  ['validnumberformatshash',['ValidNumberFormatsHash',['../../../Swagger/html/namespace_swagger.html#a6a8592cb2d5bd372e33c4f2b8b4c7921',1,'Swagger']]],
  ['validschemes',['ValidSchemes',['../../../Swagger/html/namespace_swagger.html#af391d54bd67278ad1b48f18d1966a55e',1,'Swagger']]],
  ['validstringformats',['ValidStringFormats',['../../../Swagger/html/namespace_swagger.html#a85ed80f64b9a131d2cf111041b25a2f8',1,'Swagger']]],
  ['validstringformatshash',['ValidStringFormatsHash',['../../../Swagger/html/namespace_swagger.html#a62c662c95294795d82e6af443711578a',1,'Swagger']]],
  ['validtypes',['ValidTypes',['../../../Mapper/html/class_mapper_1_1_mapper.html#a1bb39d56e19b84038417b65a6ed41ed5',1,'Mapper::Mapper']]],
  ['varchar',['VARCHAR',['../../../../lang/html/group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'Qore::SQL::VARCHAR()'],['../../../../lang/html/group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'VARCHAR()(Global Namespace)'],['../../../SqlUtil/html/namespace_sql_util.html#a3316fb866d8fee4f0bb9f9d956f9a04d',1,'SqlUtil::VARCHAR()']]],
  ['vdiscard',['VDISCARD',['../../../../lang/html/group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'Qore::VDISCARD()'],['../../../../lang/html/group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'VDISCARD()(Global Namespace)']]],
  ['vdsusp',['VDSUSP',['../../../../lang/html/group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'Qore::VDSUSP()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'VDSUSP()(Global Namespace)']]],
  ['vendorextensions',['vendorExtensions',['../../../Swagger/html/class_swagger_1_1_object_base.html#aed2ef6533b96edd9f52f02f9c5925460',1,'Swagger::AbstractParameterObject']]],
  ['veof',['VEOF',['../../../../lang/html/group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'Qore::VEOF()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'VEOF()(Global Namespace)']]],
  ['veol',['VEOL',['../../../../lang/html/group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'Qore::VEOL()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'VEOL()(Global Namespace)']]],
  ['veol2',['VEOL2',['../../../../lang/html/group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'Qore::VEOL2()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'VEOL2()(Global Namespace)']]],
  ['verase',['VERASE',['../../../../lang/html/group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'Qore::VERASE()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'VERASE()(Global Namespace)']]],
  ['version',['Version',['../../../HttpServer/html/class_http_server_1_1_http_server.html#abda322a2b64c3c6ae706454d554d189b',1,'HttpServer::HttpServer::Version()'],['../../../RestClient/html/class_rest_client_1_1_rest_client.html#ae80b536b758aa5018270f5cbac0bb67a',1,'RestClient::RestClient::Version()'],['../../../WebSocketClient/html/class_web_socket_client_1_1_web_socket_client.html#a9d7ebca8b26337385ece4c102fd43315',1,'WebSocketClient::WebSocketClient::Version()'],['../../../Swagger/html/class_swagger_1_1_info_object.html#a317ab2b2f6a3daaafe78da0a35e3db5a',1,'Swagger::InfoObject::version()'],['../class_schema_1_1_abstract_schema.html#a9b245c4852eeababcac556f87607ce29',1,'Schema::AbstractSchema::version()']]],
  ['version_5fcolumn',['version_column',['../class_schema_1_1_abstract_versioned_schema.html#a04a5664e0f928454f87eddcb880443a4',1,'Schema::AbstractVersionedSchema']]],
  ['version_5ftable',['version_table',['../class_schema_1_1_abstract_versioned_schema.html#ae92768484a7835db6c68c1462b2aaece',1,'Schema::AbstractVersionedSchema']]],
  ['version_5fwhere',['version_where',['../class_schema_1_1_abstract_versioned_schema.html#ac0e3c44cb6baf5234b253b125ab2ebdd',1,'Schema::AbstractVersionedSchema']]],
  ['versionmajor',['VersionMajor',['../../../../lang/html/group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'Qore::VersionMajor()'],['../../../../lang/html/group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'VersionMajor()(Global Namespace)']]],
  ['versionminor',['VersionMinor',['../../../../lang/html/group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'Qore::VersionMinor()'],['../../../../lang/html/group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'VersionMinor()(Global Namespace)']]],
  ['versionstring',['VersionString',['../../../RestClient/html/class_rest_client_1_1_rest_client.html#a387c7f8fcc1cae3940bc9924c2d60534',1,'RestClient::RestClient::VersionString()'],['../../../../lang/html/group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'Qore::VersionString()'],['../../../../lang/html/group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'VersionString()(Global Namespace)']]],
  ['versionsub',['VersionSub',['../../../../lang/html/group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'Qore::VersionSub()'],['../../../../lang/html/group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'VersionSub()(Global Namespace)']]],
  ['vintr',['VINTR',['../../../../lang/html/group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'Qore::VINTR()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'VINTR()(Global Namespace)']]],
  ['vkill',['VKILL',['../../../../lang/html/group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'Qore::VKILL()'],['../../../../lang/html/group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'VKILL()(Global Namespace)']]],
  ['vlnext',['VLNEXT',['../../../../lang/html/group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'Qore::VLNEXT()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'VLNEXT()(Global Namespace)']]],
  ['vmin',['VMIN',['../../../../lang/html/group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'Qore::VMIN()'],['../../../../lang/html/group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'VMIN()(Global Namespace)']]],
  ['vquit',['VQUIT',['../../../../lang/html/group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'Qore::VQUIT()'],['../../../../lang/html/group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'VQUIT()(Global Namespace)']]],
  ['vreprint',['VREPRINT',['../../../../lang/html/group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'Qore::VREPRINT()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'VREPRINT()(Global Namespace)']]],
  ['vstart',['VSTART',['../../../../lang/html/group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'Qore::VSTART()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'VSTART()(Global Namespace)']]],
  ['vstatus',['VSTATUS',['../../../../lang/html/group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'Qore::VSTATUS()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'VSTATUS()(Global Namespace)']]],
  ['vstop',['VSTOP',['../../../../lang/html/group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'Qore::VSTOP()'],['../../../../lang/html/group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'VSTOP()(Global Namespace)']]],
  ['vsusp',['VSUSP',['../../../../lang/html/group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'Qore::VSUSP()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'VSUSP()(Global Namespace)']]],
  ['vtime',['VTIME',['../../../../lang/html/group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'Qore::VTIME()'],['../../../../lang/html/group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'VTIME()(Global Namespace)']]],
  ['vwerase',['VWERASE',['../../../../lang/html/group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'Qore::VWERASE()'],['../../../../lang/html/group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'VWERASE()(Global Namespace)']]]
];
